 /*****************************************************************************
 * This file is a mix of the original ATMEL_EB40A_Target.js from              *
 * CrossWorks for ARM 1.5 and some new parts for the Ethernut3 board.         *
 *                                                                            *
 * THIS FILE IS PROVIDED AS IS WITH NO WARRANTY OF ANY KIND, INCLUDING THE    *
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  *
 ******************************************************************************/

function Reset()
{
  // Get the target interface into debug state for the peeks and pokes
  TargetInterface.beginDebugAccess();

  // Disable watchdog
  TargetInterface.pokeWord(0xFFFF8000, 0x2340);
  // Initialize the WD Clock Mode Register
  TargetInterface.pokeWord(0xFFFF8004, 0x373F);
  // Restart the timer
  TargetInterface.pokeWord(0xFFFF8008, 0xC071);
  // Enable the watchdog
  TargetInterface.pokeWord(0xFFFF8000, 0x2341);
  // Enable internal reset generation
  TargetInterface.pokeWord(0xFFFF8000, 0x2343);

  // Set a breakpoint on reset vector
  TargetInterface.setICEBreakerBreakpoint(0, 0x00000000, 0x00000000, 0x00000000, 0xFFFFFFFF, 0x100, 0xF7);

  // Release target from debug state.
  TargetInterface.endDebugAccess(true);

  // Wait for CPU to reset and hit the breakpoint
  TargetInterface.waitForDebugState(5000);

  // Reset the Embedded ICE macrocell
  TargetInterface.trst();

  // Disable the watchdog
  TargetInterface.pokeWord(0xFFFF8000, 0x2340);
}

function EBIInit()
{
  //
  // Setup the memory interface for Ethernut3
  //	
  TargetInterface.pokeWord(0xFFE00000, 0x1000212D); // EBI_CSR0 
  TargetInterface.pokeWord(0xFFE00004, 0x20003029); // EBI_CSR1
  TargetInterface.pokeWord(0xFFE00008, 0x21002026); // EBI_CSR2
  TargetInterface.pokeWord(0xFFE0000C, 0x30000000); // EBI_CSR3
  TargetInterface.pokeWord(0xFFE00010, 0x22002E3E); // EBI_CSR4
  TargetInterface.pokeWord(0xFFE00014, 0x50000000); // EBI_CSR5
  TargetInterface.pokeWord(0xFFE00018, 0x60000000); // EBI_CSR6
  TargetInterface.pokeWord(0xFFE0001C, 0x70000000); // EBI_CSR7

  // 
  // Maximum address space of 4 MBytes per chip select.
  // This occupies A0 to A21.
  //
  TargetInterface.pokeWord(0xFFE00024, 5);

  // 
  // Cancel remapping, put SRAM at zero.
  // 
  TargetInterface.pokeWord(0xFFE00020, 1);
}

function RAMReset()
{
  Reset();
  EBIInit();
}

function FLASHReset()
{
  Reset();
  EBIInit();
}
